@@ -1,4 +1,4 @@
-import os
+import pathlib
 import shutil
 
 import pytest
@@ -16,22 +16,21 @@ def test_create_in_existing_directory(monkeypatch, tmpdir):
         tmpdir.dirpath(), "test_project_dir", TemplateT.REPAYMENT
     )
     for d in TEMPLATE_PROJECT_DIRS:
-        assert os.path.isdir(os.path.join(tmpdir.dirpath(), "test_project_dir", d))
+        assert (pathlib.Path(tmpdir.dirpath()) / "test_project_dir" / d).is_dir()
     for file in TEMPLATE_PROJECT_FILES[TemplateT.REPAYMENT]:
-        assert os.path.exists(os.path.join(tmpdir.dirpath(), "test_project_dir", file))
-    assert os.path.exists(
-        os.path.join(tmpdir.dirpath(), "test_project_dir", "tktl.yaml")
-    )
+        assert (pathlib.Path(tmpdir.dirpath()) / "test_project_dir" / file).exists()
+    assert (pathlib.Path(tmpdir.dirpath()) / "test_project_dir" / "tktl.yaml").exists()
 
 
 def test_create_project():
     ProjectManager.init_project(None, "sample_project", TemplateT.REPAYMENT)
+    sample_project_dir = pathlib.Path("sample_project")
     for file in TEMPLATE_PROJECT_FILES[TemplateT.REPAYMENT]:
-        assert os.path.exists(os.path.join("sample_project", file))
-    assert os.path.exists(os.path.join("sample_project", "tktl.yaml"))
+        assert (sample_project_dir / file).is_file()
+    assert (sample_project_dir / "tktl.yaml").exists()
 
     for d in TEMPLATE_PROJECT_DIRS:
-        assert os.path.isdir(os.path.join("sample_project", d))
+        assert (sample_project_dir / d).is_dir()
     shutil.rmtree("sample_project")
 
 
