@@ -145,8 +145,7 @@ def to_uuid(_, __, x):
 
 
 def get_secrets(secrets_repository) -> Optional[Dict[str, str]]:
-    if secrets_repository is not None:
-        secrets_manager = SecretsManager(secrets_repository=secrets_repository)
-        return secrets_manager.get_secrets()
-    else:
+    if secrets_repository is None:
         return None
+    secrets_manager = SecretsManager(secrets_repository=secrets_repository)
+    return secrets_manager.get_secrets()
