@@ -1,9 +1,9 @@
 from typing import Optional, Union
 
 from pyarrow.flight import FlightClient  # type: ignore
+from taktile_client.http_client import API
 from taktile_types.enums.instance import ServiceType
 
-from tktl.core.clients.http_client import API
 from tktl.core.clients.taktile import DeploymentApiClient
 from tktl.core.loggers import LOG, Logger, set_verbosity
 from tktl.core.schemas.repository import Endpoint
@@ -87,7 +87,8 @@ class Client(object):
 
     def get_deployment_location(self):
         deployment = self.taktile_client.get_deployment_by_branch_name(
-            repository_name=self.repository_name, branch_name=self.branch_name,
+            repository_name=self.repository_name,
+            branch_name=self.branch_name,
         )
         return self.format_url(deployment.public_docs_url)
 
