@@ -1,15 +1,15 @@
-import os
+import pathlib
 import time
-from typing import Dict
+from typing import Dict, Optional
 
 import docker  # type: ignore
 import requests
 from requests.exceptions import RequestException
 
-from tktl.commands.health import GetGrpcHealthCommand, GetRestHealthCommand
+from tktl.commands.health import check_grpc_health, check_rest_health
 from tktl.core.config import settings
-from tktl.core.exceptions import APIClientException, MissingDocker
-from tktl.core.loggers import LOG, MUTE_LOG
+from tktl.core.exceptions import DockerBuildError, MissingDocker
+from tktl.core.loggers import LOG
 
 TESTING_DOCKERFILE = "Dockerfile.taktile-cli-testing"
 MULTI_STAGE_BUILD_STEP_NAME = "build_step"
@@ -19,12 +19,12 @@ class DockerManager:
     def __init__(self, path):
         try:
             self._client = docker.from_env()
-            self._path = path
+            self._path = pathlib.Path(path)
         except docker.errors.DockerException as err:
             raise MissingDocker from err
 
     def get_docker_file(self) -> str:
-        with open(os.path.join(self._path, ".buildfile")) as fp:
+        with open(self._path / ".buildfile") as fp:
             return fp.read()
 
     def stream_logs(self, container) -> None:
@@ -35,7 +35,11 @@ class DockerManager:
         self._client.images.remove(image, force=True)
 
     def build_image(
-        self, dockerfile: str, cache: bool, prune: bool, buildargs: Dict = None
+        self,
+        dockerfile: str,
+        cache: bool,
+        prune: bool,
+        buildargs: Optional[Dict] = None,
     ) -> str:
 
         if prune:
@@ -51,28 +55,46 @@ class DockerManager:
         LOG.log(
             f"Multistage dockerfile, building target {MULTI_STAGE_BUILD_STEP_NAME}..."
         )
-        image, stream = self._client.images.build(
-            path=self._path,
-            dockerfile=dockerfile,
-            tag="taktile-cli-test",
-            nocache=not cache,
-            target=MULTI_STAGE_BUILD_STEP_NAME,
-            buildargs=buildargs,
-            forcerm=True,
-        )
+        try:
+            image, stream = self._client.images.build(
+                path=str(self._path),
+                dockerfile=dockerfile,
+                tag="taktile-cli-test",
+                nocache=not cache,
+                target=MULTI_STAGE_BUILD_STEP_NAME,
+                buildargs=buildargs,
+                forcerm=True,
+            )
 
-        for chunk in stream:
-            if "stream" in chunk:
-                for line in chunk["stream"].splitlines():
-                    LOG.trace("> " + line)
+            for chunk in stream:
+                if "stream" in chunk:
+                    for line in chunk["stream"].splitlines():
+                        LOG.trace("> " + line)
 
-        return image.id
+            return image.id
+        except docker.errors.BuildError as e:
+            for chunk in e.build_log:
+                if "stream" in chunk:
+                    for line in chunk["stream"].splitlines():
+                        LOG.log("> " + line)
+            raise DockerBuildError(e.msg)
 
-    def test_import(self, image_id: str):
+    def test_import(self, image_id: str, secrets: Optional[Dict[str, str]] = None):
+        if secrets is None:
+            secrets = {}
         client_name = "tktl" if not settings.FUTURE_ENDPOINTS else "client"
         command = f"python -c 'from src.endpoints import {client_name}'"
         try:
-            container = self._client.containers.run(image_id, command, detach=True,)
+            container = self._client.containers.run(
+                image_id,
+                command,
+                detach=True,
+                environment={
+                    "TAKTILE_GIT_SHA": "local-run",
+                    "TAKTILE_GIT_REF": "local-run",
+                    **secrets,
+                },
+            )
             self.stream_logs(container)
 
             status = container.wait()
@@ -80,10 +102,25 @@ class DockerManager:
         finally:
             container.remove()
 
-    def test_endpoint_sample(self, image_id: str):
+    def test_endpoint_sample(
+        self,
+        image_id: str,
+        secrets: Optional[Dict[str, str]] = None,
+    ):
+        if secrets is None:
+            secrets = {}
         try:
             command = f"python /app/scripts/endpoint_sample_test{'_future' if settings.FUTURE_ENDPOINTS else ''}.py"
-            container = self._client.containers.run(image_id, command, detach=True)
+            container = self._client.containers.run(
+                image_id,
+                command,
+                detach=True,
+                environment={
+                    "TAKTILE_GIT_SHA": "local-run",
+                    "TAKTILE_GIT_REF": "local-run",
+                    **secrets,
+                },
+            )
             self.stream_logs(container)
 
             status = container.wait()
@@ -91,10 +128,19 @@ class DockerManager:
         finally:
             container.remove()
 
-    def test_unittest(self, image_id: str):
+    def test_unittest(self, image_id: str, secrets: Optional[Dict[str, str]] = None):
+        if secrets is None:
+            secrets = {}
         try:
             container = self._client.containers.run(
-                image_id, "python -m pytest ./user_tests/", detach=True
+                image_id,
+                "python -m pytest ./user_tests/",
+                detach=True,
+                environment={
+                    "TAKTILE_GIT_SHA": "local-run",
+                    "TAKTILE_GIT_REF": "local-run",
+                    **secrets,
+                },
             )
             self.stream_logs(container)
 
@@ -104,26 +150,48 @@ class DockerManager:
             container.remove()
 
     def run_rest_container(
-        self, image_id: str, detach: bool = True, auth_enabled: bool = True
+        self,
+        image_id: str,
+        detach: bool = True,
+        auth_enabled: bool = True,
+        reload: bool = False,
+        secrets: Optional[Dict[str, str]] = None,
     ):
+        if secrets is None:
+            secrets = {}
+        assets_path = (self._path / "assets").resolve()
+        src_path = (self._path / "src").resolve()
         return self._client.containers.run(
             image_id,
+            entrypoint="/start-reload.sh" if reload else "/start-rest.sh",
             detach=detach,
-            entrypoint="/start-rest.sh",
             environment={
                 "AUTH_ENABLED": auth_enabled,
                 "TAKTILE_GIT_SHA": "local-run",
                 "TAKTILE_GIT_REF": "local-run",
+                **secrets,
             },
             ports={"80/tcp": 8080},
             remove=True,
             stderr=True,
             stdout=True,
+            volumes=[
+                f"{assets_path}:/app/assets",
+                f"{src_path}:/app/src",
+            ]
+            if reload
+            else [],
         )
 
     def run_arrow_container(
-        self, image_id: str, detach: bool = True, auth_enabled: bool = True
+        self,
+        image_id: str,
+        detach: bool = True,
+        auth_enabled: bool = True,
+        secrets: Optional[Dict[str, str]] = None,
     ):
+        if secrets is None:
+            secrets = {}
         return self._client.containers.run(
             image_id,
             detach=detach,
@@ -132,6 +200,7 @@ class DockerManager:
                 "AUTH_ENABLED": auth_enabled,
                 "TAKTILE_GIT_SHA": "local-run",
                 "TAKTILE_GIT_REF": "local-run",
+                **secrets,
             },
             ports={"5005/tcp": 5005},
             remove=True,
@@ -140,13 +209,22 @@ class DockerManager:
         )
 
     def run_containers(
-        self, image_id: str, detach: bool = True, auth_enabled: bool = True
+        self,
+        image_id: str,
+        detach: bool = True,
+        auth_enabled: bool = True,
+        reload: bool = False,
+        secrets: Optional[Dict[str, str]] = None,
     ):
         arrow_container = self.run_arrow_container(
-            image_id=image_id, detach=detach, auth_enabled=auth_enabled
+            image_id=image_id, detach=detach, auth_enabled=auth_enabled, secrets=secrets
         )
         rest_container = self.run_rest_container(
-            image_id=image_id, detach=detach, auth_enabled=auth_enabled
+            image_id=image_id,
+            detach=detach,
+            auth_enabled=auth_enabled,
+            reload=reload,
+            secrets=secrets,
         )
         return arrow_container, rest_container
 
@@ -173,36 +251,27 @@ class DockerManager:
         auth_enabled: bool = True,
         timeout: int = 7,
         retries: int = 7,
+        secrets: Optional[Dict[str, str]] = None,
     ):
+        if secrets is None:
+            secrets = {}
         arrow_container, rest_container = self.run_containers(
-            image_id=image_id, detach=True, auth_enabled=auth_enabled
-        )
-        grpc_health_cmd = GetGrpcHealthCommand(
-            branch_name="",
-            repository="",
-            local=True,
-            logger=MUTE_LOG if not LOG.VERBOSE else LOG,
-            skip_auth=True,
-        )
-        rest_health_cmd = GetRestHealthCommand(
-            branch_name="",
-            repository="",
-            local=True,
-            logger=MUTE_LOG if not LOG.VERBOSE else LOG,
-            skip_auth=True,
+            image_id=image_id, detach=True, auth_enabled=auth_enabled, secrets=secrets
         )
 
         try:
-            for _ in range(retries):
+            while True:
                 try:
                     time.sleep(timeout)
-                    rest_response = rest_health_cmd.execute()
-                    grpc_response = grpc_health_cmd.execute()
-                    return rest_response, grpc_response, arrow_container, rest_container
-                except (APIClientException, Exception):
-                    pass
+                    check_grpc_health()
+                    check_rest_health()
+                    return arrow_container, rest_container
+                except Exception:
+                    if retries > 0:
+                        retries -= 1
+                    else:
+                        raise
 
-            return None, None, arrow_container, rest_container
         finally:
             if kill_on_success:
                 arrow_container.kill()
@@ -222,4 +291,6 @@ def _get_profiling_version() -> str:
         except RequestException as e:
             LOG.debug(f"Failed to fetch profiling version from Info {e}")
             profiling_version = "latest"
-        return profiling_version
+        # Using py3.7 as it is currently being used in Operator
+        # TODO - Replace after finishing https://github.com/taktile-org/taktile-services/issues/2867
+        return f"{profiling_version}-py3.7"
