@@ -4,11 +4,10 @@ from typing import Dict, List, Optional, Union
 import certifi
 from pydantic import UUID4, BaseModel, validator
 from taktile_types.enums.instance import ServiceType
+from taktile_types.enums.repository.access import AccessKind
 
 from tktl.constants import NON_EXISTING_DEPLOYMENT_DEFAULT_STATUS, URL_UNAVAILABLE
 from tktl.core.config import settings
-from tktl.core.t import AccessKind
-from tktl.core.utils import flatten
 
 
 class TablePrintableBaseModelMixin:
@@ -81,7 +80,12 @@ class RepositoryDeployment(BaseModel, TablePrintableBaseModelMixin):
         return value or 0
 
     def table_repr(self, subset=None):
-        as_dict = self.dict(exclude={"service_type", "endpoints",})
+        as_dict = self.dict(
+            exclude={
+                "service_type",
+                "endpoints",
+            }
+        )
         repr = {}
         repr["ID"] = str(as_dict["id"])
         repr["BRANCH"] = as_dict["git_ref"]
@@ -146,16 +150,6 @@ class Repository(BaseModel, TablePrintableBaseModelMixin):
         return as_dict
 
 
-class RepositoryList(BaseModel):
-    __root__: List[Repository]
-
-    def get_repositories(self) -> List[Repository]:
-        return [r for r in self.__root__]
-
-    def get_deployments(self) -> List[RepositoryDeployment]:
-        return flatten([[d for d in r.deployments] for r in self.__root__])
-
-
 class ReportResponse(BaseModel):
     deployment_id: UUID4
     endpoint_name: str
