@@ -1,9 +1,9 @@
 import functools
 import json
 from io import BytesIO
-from typing import Dict, List, Sequence, Type, Union
+from typing import Dict, List, Optional, Sequence, Type, Union
 
-import pyarrow
+import pyarrow  # type: ignore
 from pyarrow import json as j
 
 
@@ -28,17 +28,17 @@ def _get_final_serializer(initial_type: Type, final_type: Type):
         elif initial_type == dict:
             return "FINAL_first"
         else:
-            raise
+            raise ValueError()
     return None
 
 
 def add_deserializing_metadata(
     table: pyarrow.Table,
     *,
-    deserializers: List[str] = None,
-    serializing_cls: str = None
+    deserializers: Optional[List[str]] = None,
+    serializing_cls: Optional[str] = None
 ) -> pyarrow.Table:
-    metadata = {}
+    metadata: Dict[str, Union[str, bytes]] = {}
     if deserializers:
         metadata["DESERIALIZERS"] = json.dumps(deserializers).encode()
     if serializing_cls:
