@@ -12,7 +12,10 @@ class TypedEndpoint(GenericEndpoint):
 
     @staticmethod
     def supported(
-        *, X: XType = None, y: YType = None, profile: t.Optional[str] = None,
+        *,
+        X: XType = None,
+        y: YType = None,
+        profile: t.Optional[str] = None,
     ) -> bool:
         return (
             profile is None
